BusinessDetails class
Constructors
- BusinessDetails()
-
BusinessDetails.fromJson(Map<
String, dynamic> json)
Properties
- agreedToBusinessAndEthicalTermsAndPolicies ↔ bool
-
getter/setter pair
- businessRegistrationNumber ↔ String
-
getter/setter pair
- cashOnDeliveryEnabled ↔ bool
-
getter/setter pair
- city ↔ String
-
getter/setter pair
- country ↔ String
-
getter/setter pair
- curbsidePickUpEnabled ↔ bool
-
getter/setter pair
- deliveredAndPreparedBySpinachShopperEnabled ↔ bool
-
getter/setter pair
- deliveredBySpinachShopperEnabled ↔ bool
-
getter/setter pair
- deliverToDoorStepEnabled ↔ bool
-
getter/setter pair
- driveThroughPickUpEnabled ↔ bool
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inStorePickUpEnabled ↔ bool
-
getter/setter pair
- numberOfLocations ↔ int
-
getter/setter pair
- payByCardOnDeliveryAndPickupEnabled ↔ bool
-
getter/setter pair
- payByCardViaSpinachEnabled ↔ bool
-
getter/setter pair
- registeredAddress ↔ String
-
getter/setter pair
- retailerID ↔ String
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shopperHelperSupportRequired ↔ bool
-
getter/setter pair
- state ↔ String
-
getter/setter pair
- zip ↔ String
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited