RestClient class

Constructors

RestClient(String _apiKey, String _host, String _baseUrl)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getByQueriesWithToken(String path, Map<String, dynamic> queries) → Future<Response>
getWithKey(String path, Map<String, dynamic> queries) → Future<Response>
getWithToken(String path) → Future<Response>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
postWithKey(String path, Map<String, dynamic> body) → Future<Response>
postWithQueriesAndToken(String _path, Map<String, dynamic> _body, Map<String, dynamic> queries) → Future<Response>
postWithToken(String _path, Map<String, dynamic> _body) → Future<Response>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited